@@ -183,11 +183,13 @@ class scpQCA:
                     Q+=str(candidate[i][j])+'=='+str(values[r][j])+' & '
                 Q=Q[:-3]
 
-                flag=True if (Q=='' or len(self.data.query(Q))==0) else False
-                for n in self.necessity[decision_label]:
-                    if n in Q:
-                        flag=True
-                if flag:
+                # flag=True if (Q=='' or len(self.data.query(Q))==0) else False
+                # for n in self.necessity[decision_label]:
+                #     if n in Q:
+                #         flag=True
+                # if flag:
+                #     continue
+                if Q=='' or len(self.data.query(Q))==0:
                     continue
                    
                 result=self.data.query(Q)
@@ -396,11 +398,11 @@ class scpQCA:
     #     print(np.var(lr),np.var(dtr),np.var(ratio1),np.var(ratio5))
     #     return
 
-# if __name__=="__main__":
-#     data=pd.read_csv(r'E:\CCDA-PC\my paper\scpQCA\SMR一拒\QCA数据\WeinbergGould1993set.csv', encoding='ISO-8859-1')
-#     test=scpQCA(data,decision_name='PART',caseid='Case')
-#     configuration,issue_set=test.runQCA(decision_label=1,feature_list=list(data.columns),necessary_consistency=[0.8,0.9,1],sufficiency_consistency=[0.75,0.8,1],cutoff=[1,2],rule_length=5,unique_cover=[2])
-#     print(configuration,issue_set)
+if __name__=="__main__":
+    data=pd.read_csv(r'E:\CCDA-PC\my paper\scpQCA\SMR一拒\QCA数据\WeinbergGould1993set.csv', encoding='ISO-8859-1')
+    test=scpQCA(data,decision_name='PART',caseid='Case')
+    configuration,issue_set=test.runQCA(decision_label=1,feature_list=list(data.columns),necessary_consistency=[0.8,0.9,1],sufficiency_consistency=[0.75,0.8,1],cutoff=[1,2],rule_length=5,unique_cover=[2])
+    print(configuration,issue_set)
     # data=[[random.randint(0,100) for _ in range(7)] for _ in range(60)]
     # data=pd.DataFrame(data)
     # data.columns=['A','B','C','D','E','F','cases']
